import { expect, test } from 'vitest';
import { transformToToken } from './transform-to-token';

const initColors = [
  {
    name: 'dm chart yellow',
    color: '#ecc94b',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'dm text blue',
    color: '#63b3ed',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'green 700',
    color: '#276749',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'dm text green emphasis',
    color: '#9ae6b4',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'lm icon blue',
    color: '#2a4365',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm card background',
    color: '#ffffff',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'gray 600',
    color: '#4a5568',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'yellow 200',
    color: '#faf089',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm button',
    color: '#E2E8F0',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'green 300',
    color: '#68d391',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'dm chart red',
    color: '#e53e3e',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'gray 400',
    color: '#a0aec0',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm dashboard background',
    color: '#EDF2F7',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm text yellow',
    color: '#744210',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'pink 100',
    color: '#fed7e2',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm text secondary',
    color: '#718096',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'blue 900',
    color: '#1a365d',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'green 800',
    color: '#22543d',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'red 300',
    color: '#FC8181',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm button yellow',
    color: '#fefcbf',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm text red emphasis',
    color: '#e53e3e',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'dm chart green',
    color: '#38a169',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'lm placeholder',
    color: '#718096',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'purple 500',
    color: '#805ad5',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm chart yellow',
    color: '#faf089',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'shadow light',
    color: '#000000',
    opacity: 0.16078432,
    path: 'colors',
  },
  {
    name: 'dm footer',
    color: '#1a202c',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'red 800',
    color: '#822727',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm text blue',
    color: '#2a4365',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'purple 300',
    color: '#b794f4',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'purple 100',
    color: '#e9d8fd',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'dm background blue',
    color: '#1a365d',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'dm text red default',
    color: '#f56565',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'gray 700',
    color: '#2d3748',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm button blue',
    color: '#bee3f8',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'dm icon default',
    color: '#e2e8f0',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'green 600',
    color: '#2f855a',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'yellow 100',
    color: '#fefcbf',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'blue 100',
    color: '#bee3f8',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'dm background yellow',
    color: '#5f370e',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'blue 650',
    color: '#2a4365',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'dm text green default',
    color: '#68d391',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'lm bar line',
    color: '#a0aec0',
    opacity: 0.4,
    path: 'ui / light mode',
  },
  {
    name: 'dm background green',
    color: '#1c4532',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'dm button blue',
    color: '#2b6cb0',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'gray 100',
    color: '#edf2f7',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'dm button yellow',
    color: '#975a16',
    opacity: 1,
    path: 'ui / dark mode',
  },
  /* 3 different blue colors in the same path */
  {
    name: 'lm icon blue',
    color: '#bee3f8',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm icon blue',
    color: '#0000ff',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm text default',
    color: '#2d3748',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm icon red',
    color: '#c53030',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm text green default',
    color: '#22543d',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm icon green',
    color: '#276749',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'shadow dark',
    color: '#000000',
    opacity: 0.69803923,
    path: 'colors',
  },
  {
    name: 'lm chart background',
    color: '#E2E8F0',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'yellow 050',
    color: '#fffff0',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'green 100',
    color: '#c6f6d5',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm sidebar',
    color: '#1a202c',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'dm label',
    color: '#a0aec0',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'green 050',
    color: '#f0fff4',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'dm button green',
    color: '#2f855a',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'lm label',
    color: '#4a5568',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm button active',
    color: '#a0aec0',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'dm icon secondary',
    color: '#718096',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'dm chart background',
    color: '#4a5568',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'lm axis line',
    color: '#a0aec0',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'dm button yellow[DONTUSE]',
    color: '#fefcbf',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'dm sidebar',
    color: '#171923',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'dm text emphasis',
    color: '#edf2f7',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'lm chart green',
    color: '#68d391',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm background blue',
    color: '#ebf8ff',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'red 100',
    color: '#FED7D7',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'dm text default',
    color: '#a0aec0',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'red 500',
    color: '#e53e3e',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'yellow 800',
    color: '#744210',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'blue 050',
    color: '#ebf8ff',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'gray 800',
    color: '#1a202c',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm background yellow',
    color: '#fffff0',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'dm chart accent',
    color: '#9f7aea',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'lm shadow',
    color: '#000000',
    opacity: 0.2,
    path: 'ui / light mode',
  },
  {
    name: 'dm text red emphasis',
    color: '#FC8181',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'dm input',
    color: '#4a5568',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'dm chart accent alt',
    color: '#ecc94b',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'lm button green',
    color: '#c6f6d5',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'red 600',
    color: '#c53030',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm icon secondary',
    color: '#e2e8f0',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'dm text yellow',
    color: '#faf089',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'green 500',
    color: '#38a169',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'shadow mid',
    color: '#000000',
    opacity: 0.6,
    path: 'colors',
  },
  {
    name: 'lm text green emphasis',
    color: '#38a169',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'blue 700',
    color: '#2c5282',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm text red default',
    color: '#822727',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm footer',
    color: '#e2e8f0',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm text emphasis',
    color: '#000000',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'dm card background',
    color: '#2d3748',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'lm chart accent',
    color: '#b794f4',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'white',
    color: '#ffffff',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'dm button default',
    color: '#4a5568',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'lm input',
    color: '#EDF2F7',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm chart accent alt',
    color: '#faf089',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'gray 200',
    color: '#e2e8f0',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm icon yellow',
    color: '#744210',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'dm dashboard background',
    color: '#1a202c',
    opacity: 1,
    path: 'ui / dark mode',
  },
  {
    name: 'lm icon default',
    color: '#A0AEC0',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'yellow 700',
    color: '#975a16',
    opacity: 1,
    path: 'colors',
  },
  {
    name: 'lm background green',
    color: '#f0fff4',
    opacity: 1,
    path: 'ui / light mode',
  },
  {
    name: 'lm chart red',
    color: '#FC8181',
    opacity: 1,
    path: 'ui / light mode',
  },
];

test('transform colors to tokens', () => {
  const result = transformToToken(initColors);

  expect(result).toMatchSnapshot();
});
